# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2016-12-02 06:11
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='AllocateRecord',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('request_no', models.CharField(max_length=128, verbose_name='\u8bf7\u6c42id')),
                ('notify_id', models.IntegerField(verbose_name='\u901a\u77e5id')),
                ('app_id', models.CharField(max_length=128, verbose_name='appid \u5bf9\u5e94 merchantId')),
                ('operator_id', models.PositiveSmallIntegerField(verbose_name='\u64cd\u4f5cid')),
                ('user_id', models.IntegerField(verbose_name='\u7528\u6237id\uff0c\u5bf9\u5e94userIn')),
                ('amount', models.DecimalField(decimal_places=2, max_digits=11, verbose_name='\u91d1\u989d')),
                ('desc', models.TextField(verbose_name='\u63cf\u8ff0')),
                ('create_time', models.DateTimeField(auto_now_add=True, verbose_name='\u8bb0\u5f55\u521b\u5efa\u65f6\u95f4')),
            ],
        ),
        migrations.CreateModel(
            name='PayResult',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('notify_time', models.DateTimeField(auto_now_add=True, verbose_name='\u901a\u77e5\u65f6\u95f4')),
                ('notify_type', models.CharField(max_length=128, null=True, verbose_name='\u901a\u77e5\u7c7b\u578b')),
                ('notify_id', models.IntegerField(verbose_name='\u901a\u77e5id')),
                ('order_id', models.IntegerField(verbose_name='\u8ba2\u5355id')),
                ('total_fee', models.DecimalField(decimal_places=2, default=0, max_digits=11, verbose_name='\u8ba2\u5355\u603b\u989d')),
                ('cash_fee', models.DecimalField(decimal_places=2, default=0, max_digits=11, verbose_name='\u5b9e\u9645\u652f\u4ed8\u91d1\u989d')),
                ('coupon_fee', models.DecimalField(decimal_places=2, default=0, max_digits=11, verbose_name='\u4ee3\u91d1\u5238\u6216\u8005\u4f18\u60e0\u91d1\u989d')),
                ('coupon_count', models.IntegerField(default=0, verbose_name='\u4ee3\u91d1\u5238\u6216\u7acb\u51cf\u4f18\u60e0\u4f7f\u7528\u6570\u91cf')),
                ('pay_time', models.DateTimeField(auto_now_add=True, verbose_name='\u652f\u4ed8\u65f6\u95f4')),
                ('pay_way', models.IntegerField(null=True, verbose_name='\u652f\u4ed8\u7c7b\u578b')),
                ('app_id', models.CharField(max_length=64, null=True, verbose_name='app id')),
                ('pay_type', models.CharField(blank=True, max_length=64, null=True, verbose_name='\u652f\u4ed8\u7c7b\u578b')),
                ('create_time', models.DateTimeField(auto_now_add=True, verbose_name='\u8bb0\u5f55\u521b\u5efa\u65f6\u95f4')),
            ],
        ),
        migrations.CreateModel(
            name='RefundRecord',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('notify_id', models.IntegerField(verbose_name='\u901a\u77e5id')),
                ('amount', models.DecimalField(decimal_places=2, max_digits=11, verbose_name='\u8ba1\u5212\u9000\u56de\u91d1\u989d')),
                ('confirm_amount', models.DecimalField(decimal_places=2, max_digits=11, verbose_name='\u5b9e\u9645\u9000\u56de\u91d1\u989d')),
                ('order_id', models.IntegerField(verbose_name='\u8ba2\u5355id')),
                ('refund_id', models.CharField(max_length=64, verbose_name='\u9000\u6b3eid\uff0c\u7531\u4f1a\u5458\u5b9d\u8fd4\u56de')),
                ('user_id', models.IntegerField(verbose_name='\u9000\u6b3e\u7528\u6237id\uff0c\u5373common api\u7684\u7528\u6237id')),
                ('create_time', models.DateTimeField(auto_now_add=True, verbose_name='\u8bb0\u5f55\u521b\u5efa\u65f6\u95f4')),
            ],
        ),
    ]
