#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
author lilx
created on 2017/1/7
 """
from __future__ import unicode_literals, absolute_import
from django.conf import settings


config = settings.ES

HOSTS = config['HOSTS']
INDEX = config['INDEX']